@@ -67,7 +67,7 @@ NameFilterWidget::NameFilterWidget(SortedDirModel* model)
     mLineEdit = new QLineEdit;
 
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(2);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mLineEdit);
@@ -75,7 +75,7 @@ NameFilterWidget::NameFilterWidget(SortedDirModel* model)
     QTimer* timer = new QTimer(this);
     timer->setInterval(350);
     timer->setSingleShot(true);
-    connect(timer, SIGNAL(timeout()), SLOT(applyNameFilter()));
+    connect(timer, &QTimer::timeout, this, &NameFilterWidget::applyNameFilter);
 
     connect(mLineEdit, SIGNAL(textChanged(QString)),
             timer, SLOT(start()));
@@ -110,12 +110,12 @@ DateFilterWidget::DateFilterWidget(SortedDirModel* model)
     mDateWidget = new DateWidget;
 
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mDateWidget);
 
-    connect(mDateWidget, SIGNAL(dateChanged(QDate)),
-            SLOT(applyDateFilter()));
+    connect(mDateWidget, &DateWidget::dateChanged,
+            this, &DateFilterWidget::applyDateFilter);
     connect(mModeComboBox, SIGNAL(currentIndexChanged(int)),
             SLOT(applyDateFilter()));
 
@@ -147,7 +147,7 @@ RatingFilterWidget::RatingFilterWidget(SortedDirModel* model)
     mRatingWidget->setMaxRating(10);
 
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mRatingWidget);
 
@@ -190,7 +190,7 @@ TagFilterWidget::TagFilterWidget(SortedDirModel* model)
     mTagComboBox = new QComboBox;
 
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mModeComboBox);
     layout->addWidget(mTagComboBox);
 
@@ -255,7 +255,7 @@ public:
         closeButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
         int size = IconSize(KIconLoader::Small);
         closeButton->setIconSize(QSize(size, size));
-        connect(closeButton, SIGNAL(clicked()), SLOT(deleteLater()));
+        connect(closeButton, &QAbstractButton::clicked, this, &QObject::deleteLater);
         QHBoxLayout* layout = new QHBoxLayout(this);
         layout->setMargin(2);
         layout->setSpacing(2);
@@ -290,11 +290,22 @@ FilterController::FilterController(QFrame* frame, SortedDirModel* dirModel)
     FlowLayout* layout = new FlowLayout(mFrame);
     layout->setSpacing(2);
 
-    addAction(i18nc("@action:inmenu", "Filter by Name"), SLOT(addFilterByName()));
-    addAction(i18nc("@action:inmenu", "Filter by Date"), SLOT(addFilterByDate()));
+    addAction(i18nc("@action:inmenu", "Filter by Name"),
+              SLOT(addFilterByName()),
+              QKeySequence(Qt::CTRL + Qt::Key_I));
+
+    addAction(i18nc("@action:inmenu", "Filter by Date"),
+              SLOT(addFilterByDate()),
+              QKeySequence());
+
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-    addAction(i18nc("@action:inmenu", "Filter by Rating"), SLOT(addFilterByRating()));
-    addAction(i18nc("@action:inmenu", "Filter by Tag"), SLOT(addFilterByTag()));
+    addAction(i18nc("@action:inmenu", "Filter by Rating"),
+              SLOT(addFilterByRating()),
+              QKeySequence());
+
+    addAction(i18nc("@action:inmenu", "Filter by Tag"),
+              SLOT(addFilterByTag()),
+              QKeySequence());
 #endif
 }
 
@@ -334,9 +345,10 @@ void FilterController::slotFilterWidgetClosed()
 }
 
 
-void FilterController::addAction(const QString& text, const char* slot)
+void FilterController::addAction(const QString& text, const char* slot, const QKeySequence shortcut)
 {
     QAction* action = new QAction(text, q);
+    action->setShortcut(shortcut);
     QObject::connect(action, SIGNAL(triggered()), q, slot);
     mActionList << action;
 }
@@ -352,7 +364,7 @@ void FilterController::addFilter(QWidget* widget)
     mFrame->layout()->addWidget(container);
 
     mFilterWidgetCount++;
-    QObject::connect(container, SIGNAL(destroyed()), q, SLOT(slotFilterWidgetClosed()));
+    QObject::connect(container, &QObject::destroyed, q, &FilterController::slotFilterWidgetClosed);
 }
 
 } // namespace
