@@ -27,13 +27,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // KDE
 #include <KAboutData>
-#include <QCommandLineParser>
 #include <KLocalizedString>
 #include <QLocale>
 
 // Local
 #include <lib/about.h>
-#include <lib/imageformats/imageformats.h>
 #include "importdialog.h"
 
 int main(int argc, char *argv[])
@@ -66,7 +64,7 @@ int main(int argc, char *argv[])
         qWarning() << i18n("Too many arguments.");
         parser.showHelp();
     }
-    QString urlString = parser.positionalArguments().first();
+    QString urlString = parser.positionalArguments().constFirst();
     QUrl url = QUrl::fromUserInput(urlString, QDir::currentPath(), QUrl::AssumeLocalFile);
     if (!url.isValid()) {
         qCritical() << i18n("Invalid source folder.");
@@ -74,8 +72,6 @@ int main(int argc, char *argv[])
     }
     QString deviceUdi = parser.isSet("udi") ? parser.value("udi") : QString();
 
-    Gwenview::ImageFormats::registerPlugins();
-
     Gwenview::ImportDialog* dialog = new Gwenview::ImportDialog();
     dialog->show();
     QMetaObject::invokeMethod(dialog, "setSourceUrl", Qt::QueuedConnection, Q_ARG(QUrl, url), Q_ARG(QString, deviceUdi));
