@@ -75,7 +75,7 @@ ZoomSlider::ZoomSlider(QWidget* parent)
     d->mSlider->setOrientation(Qt::Horizontal);
 
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     layout->addWidget(d->mZoomOutButton);
     layout->addWidget(d->mSlider);
