@@ -54,14 +54,14 @@ void TransformImageOperationTest::testRotate90()
 
     bool ok = image.load(url.toLocalFile());
     QVERIFY2(ok, "Could not load 'test.png'");
-    QMatrix matrix = ImageUtils::transformMatrix(ROT_90);
+    QTransform matrix = ImageUtils::transformMatrix(ROT_90);
     image = image.transformed(matrix);
 
     Document::Ptr doc = DocumentFactory::instance()->load(url);
 
     TransformImageOperation* op = new TransformImageOperation(ROT_90);
     QEventLoop loop;
-    connect(doc.data(), SIGNAL(allTasksDone()), &loop, SLOT(quit()));
+    connect(doc.data(), &Document::allTasksDone, &loop, &QEventLoop::quit);
     op->applyToDocument(doc);
     loop.exec();
 
